@@ -23,28 +23,51 @@ from alastria_service_client.validators import (
     Address,
 )
 from alastria_identity.types import JwtToken, AlastriaToken
-from network_service_client.client import AClient as ANetworkClient, Client as NetworkClient, Network as NetworkDTO, NetworksNames
+from network_service_client.client import (
+    AClient as ANetworkClient,
+    Client as NetworkClient,
+    Network as NetworkDTO,
+    NetworksNames,
+)
 from network_service_client.enums import ContractsNames
 
 
 class AlastriaAuthService(AAlastriaAuthService):
     @staticmethod
     def public_key_to_address(public_key: str) -> str:
-        return Web3.toChecksumAddress(keys.PublicKey(decode_hex(public_key[2:])).to_address())
+        return Web3.toChecksumAddress(
+            keys.PublicKey(decode_hex(public_key[2:])).to_address()
+        )
 
     @staticmethod
     def get_did(address: str) -> str:
-        alastria_service_client: AClient = Client(service_host=settings.ALASTRIA_SERVICE_HOST)
-        network_data: NetworkDTO = NetworkClient(service_host=settings.NETWORK_SERVICE_HOST).get_network_by_name(NetworksNames.AlastriaDefaultName)
+        alastria_service_client: AClient = Client(
+            service_host=settings.ALASTRIA_SERVICE_HOST
+        )
+        network_data: NetworkDTO = NetworkClient(
+            service_host=settings.NETWORK_SERVICE_HOST
+        ).get_network_by_name(NetworksNames.AlastriaDefaultName)
         network_body = NetworkValidator(
             provider=network_data.node["path"],
-            identity_manager_contract_address=list(filter(lambda contract: contract["name"] == ContractsNames.AlastriaIdentityManager.value, network_data.contracts))[0]["address"],  
-            identity_manager_contract_abi=list(filter(lambda contract: contract["name"] == ContractsNames.AlastriaIdentityManager.value, network_data.contracts))[0]["abi"],  
+            identity_manager_contract_address=list(
+                filter(
+                    lambda contract: contract["name"]
+                    == ContractsNames.AlastriaIdentityManager.value,
+                    network_data.contracts,
+                )
+            )[0]["address"],
+            identity_manager_contract_abi=list(
+                filter(
+                    lambda contract: contract["name"]
+                    == ContractsNames.AlastriaIdentityManager.value,
+                    network_data.contracts,
+                )
+            )[0]["abi"],
             public_key_registry_contract_address="",
             public_key_registry_contract_abi="",
             credential_registry_contract_abi="",
             credential_registry_contract_address="",
-            chainId=network_data.chain_id
+            chainId=network_data.chain_id,
         )
         return alastria_service_client.identity_keys(
             address=Address(address), body=OnlyNetworkValidator(network=network_body)
@@ -76,14 +99,18 @@ class AlastriaAuthService(AAlastriaAuthService):
         )
         rs.save()
         at: dict = AlastriaToken(
-            settings.ALASTRIA_PREFIX + AlastriaAuthService.get_did(settings.ISSUER_ADDRESS)[2:],
+            settings.ALASTRIA_PREFIX
+            + AlastriaAuthService.get_did(settings.ISSUER_ADDRESS)[2:],
             settings.ALASTRIA_NODE_IP,
             "/alastria/alastria-auth/confirm",
             settings.ALASTRIA_T_NETWORK_ID,
             1,
         ).build_jwt()
         at["payload"].update(
-            {"signature_url": "/alastria/alastria-auth/signature", "request_session_id": rs.pk}
+            {
+                "signature_url": "/alastria/alastria-auth/signature",
+                "request_session_id": rs.pk,
+            }
         )
         token_service = TokenService(settings.ISSUER_PRIVATE_KEY)
         signed = token_service.sign_jwt(JwtToken(**at))
@@ -108,7 +135,12 @@ class AlastriaAuthService(AAlastriaAuthService):
 
     @staticmethod
     def validate_request_session(rs: RequestSession, format_did: str, response):
-        if rs and rs.requested_by == format_did and rs.expiration_date > now() and not rs.completed:
+        if (
+            rs
+            and rs.requested_by == format_did
+            and rs.expiration_date > now()
+            and not rs.completed
+        ):
             token_service = TokenService(settings.ISSUER_PRIVATE_KEY)
 
             rs.completed = True
@@ -132,21 +164,29 @@ class AlastriaAuthService(AAlastriaAuthService):
     def validate_signature(token: str) -> Any:
         token_service = TokenService(settings.ISSUER_PRIVATE_KEY)
         decoded = token_service.decode_jwt(token)
-        alastria_token_decoded = token_service.decode_jwt(decoded["payload"].get("alastriaToken"))
+        alastria_token_decoded = token_service.decode_jwt(
+            decoded["payload"].get("alastriaToken")
+        )
         if not token_service.verify_jwt(
             decoded["payload"].get("alastriaToken"), settings.ISSUER_PUBLIC_KEY
         ):
             return HttpResponseBadRequest("Invalid Alastria Token.")
         public_key: str = decoded.get("payload").get("pku")
-        request_session_id: int = alastria_token_decoded.get("payload").get("request_session_id")
+        request_session_id: int = alastria_token_decoded.get("payload").get(
+            "request_session_id"
+        )
         if token_service.verify_jwt(token, public_key):
             address: str = AlastriaAuthService.public_key_to_address(public_key)
             did: str = AlastriaAuthService.get_did(address)
-            rs: RequestSession = RequestSession.objects.filter(pk=request_session_id).first()
+            rs: RequestSession = RequestSession.objects.filter(
+                pk=request_session_id
+            ).first()
             format_did: str = settings.ALASTRIA_PREFIX + did[2:]
 
             return AlastriaAuthService.validate_request_session(
-                rs, format_did, AlastriaAuthService.validate_did(did, Response({"response": "OK"}))
+                rs,
+                format_did,
+                AlastriaAuthService.validate_did(did, Response({"response": "OK"})),
             )
 
         else:
